==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Bengali.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Bengali
</name>

<description>
   <am>Bengali dictionary for hunspell</am>
   <ar>Bengali dictionary for hunspell</ar>
   <be>Bengali dictionary for hunspell</be>
   <bg>Bengali dictionary for hunspell</bg>
   <bn>Bengali dictionary for hunspell</bn>
   <ca>Bengali dictionary for hunspell</ca>
   <cs>Bengali dictionary for hunspell</cs>
   <da>Bengali dictionary for hunspell</da>
   <de>Bengali dictionary for hunspell</de>
   <el>Λεξικό Μπενγκάλι για hunspell</el>
   <en>Bengali dictionary for hunspell</en>
   <es_ES>Bengali dictionary for hunspell</es_ES>
   <es>Diccionario Bengalí para hunspell</es>
   <et>Bengali dictionary for hunspell</et>
   <eu>Bengali dictionary for hunspell</eu>
   <fa>Bengali dictionary for hunspell</fa>
   <fil_PH>Bengali dictionary for hunspell</fil_PH>
   <fi>Bengali dictionary for hunspell</fi>
   <fr_BE>Bengali dictionary for hunspell</fr_BE>
   <fr>Bengali dictionary for hunspell</fr>
   <gl_ES>Bengali dictionary for hunspell</gl_ES>
   <he_IL>Bengali dictionary for hunspell</he_IL>
   <hi>Bengali dictionary for hunspell</hi>
   <hr>Bengali dictionary for hunspell</hr>
   <hu>Bengali dictionary for hunspell</hu>
   <id>Bengali dictionary for hunspell</id>
   <is>Bengali dictionary for hunspell</is>
   <it>Bengali dictionary for hunspell</it>
   <ja>Hunspell 用ベンガル語辞書</ja>
   <kk>Bengali dictionary for hunspell</kk>
   <ko>Bengali dictionary for hunspell</ko>
   <lt>Bengali dictionary for hunspell</lt>
   <mk>Bengali dictionary for hunspell</mk>
   <mr>Bengali dictionary for hunspell</mr>
   <nb_NO>Bengali dictionary for hunspell</nb_NO>
   <nb>Bengali dictionary for hunspell</nb>
   <nl_BE>Bengali dictionary for hunspell</nl_BE>
   <nl>Bengali dictionary for hunspell</nl>
   <pl>Bengali dictionary for hunspell</pl>
   <pt_BR>Bengali dictionary for hunspell</pt_BR>
   <pt>Bengali dictionary for hunspell</pt>
   <ro>Bengali dictionary for hunspell</ro>
   <ru>Bengali dictionary for hunspell</ru>
   <sk>Bengali dictionary for hunspell</sk>
   <sl>Bengali dictionary for hunspell</sl>
   <sq>Bengali dictionary for hunspell</sq>
   <sr>Bengali dictionary for hunspell</sr>
   <sv>Bengali dictionary for hunspell</sv>
   <th>Bengali dictionary for hunspell</th>
   <tr>Bengali dictionary for hunspell</tr>
   <uk>Bengali dictionary for hunspell</uk>
   <vi>Bengali dictionary for hunspell</vi>
   <zh_CN>Bengali dictionary for hunspell</zh_CN>
   <zh_HK>Bengali dictionary for hunspell</zh_HK>
   <zh_TW>Bengali dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-bn
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-bn
</uninstall_package_names>

</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Bengali.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Bengali
</name>

<description>
   <am>Bengali dictionary for hunspell</am>
   <ar>Bengali dictionary for hunspell</ar>
   <be>Bengali dictionary for hunspell</be>
   <bg>Bengali dictionary for hunspell</bg>
   <bn>Bengali dictionary for hunspell</bn>
   <ca>Bengali dictionary for hunspell</ca>
   <cs>Bengali dictionary for hunspell</cs>
   <da>Bengali dictionary for hunspell</da>
   <de>Bengalisches Wörterbuch für “Hunspell”</de>
   <el>Λεξικό Μπενγκάλι για hunspell</el>
   <en>Bengali dictionary for hunspell</en>
   <es_ES>Diccionario Bengali para hunspell</es_ES>
   <es>Diccionario Bengalí para hunspell</es>
   <et>Bengali dictionary for hunspell</et>
   <eu>Bengali dictionary for hunspell</eu>
   <fa>Bengali dictionary for hunspell</fa>
   <fil_PH>Bengali dictionary for hunspell</fil_PH>
   <fi>Bengali dictionary for hunspell</fi>
   <fr_BE>Bengali dictionary for hunspell</fr_BE>
   <fr>Bengali dictionnaire pour hunspell</fr>
   <gl_ES>Bengali dictionary for hunspell</gl_ES>
   <gu>Bengali dictionary for hunspell</gu>
   <he_IL>Bengali dictionary for hunspell</he_IL>
   <hi>Bengali dictionary for hunspell</hi>
   <hr>Bengali dictionary for hunspell</hr>
   <hu>Bengali dictionary for hunspell</hu>
   <id>Bengali dictionary for hunspell</id>
   <is>Bengali dictionary for hunspell</is>
   <it>Dizionario bengalese per hunspell</it>
   <ja>Hunspell 用ベンガル語辞書</ja>
   <kk>Bengali dictionary for hunspell</kk>
   <ko>Bengali dictionary for hunspell</ko>
   <lt>Bengali dictionary for hunspell</lt>
   <mk>Bengali dictionary for hunspell</mk>
   <mr>Bengali dictionary for hunspell</mr>
   <nb_NO>Bengali dictionary for hunspell</nb_NO>
   <nb>Bengali ordliste for hunspell</nb>
   <nl_BE>Bengali dictionary for hunspell</nl_BE>
   <nl>Bengali dictionary for hunspell</nl>
   <pl>Bengali dictionary for hunspell</pl>
   <pt_BR>Dicionário Bengali para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
   <pt>Dicionário Bengali para hunspell</pt>
   <ro>Bengali dictionary for hunspell</ro>
   <ru>Bengali dictionary for hunspell</ru>
   <sk>Bengali dictionary for hunspell</sk>
   <sl>Bengalski slovar za hunspell</sl>
   <sq>Bengali dictionary for hunspell</sq>
   <sr>Bengali dictionary for hunspell</sr>
   <sv>Bengali ordbok för hunspell</sv>
   <th>Bengali dictionary for hunspell</th>
   <tr>Hunspell için Bengalce sözlük</tr>
   <uk>Bengali dictionary for hunspell</uk>
   <vi>Bengali dictionary for hunspell</vi>
   <zh_CN>Bengali dictionary for hunspell</zh_CN>
   <zh_HK>Bengali dictionary for hunspell</zh_HK>
   <zh_TW>Bengali dictionary for hunspell</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>
</preinstall>

<install_package_names>
hunspell-bn
</install_package_names>

<postinstall>

</postinstall>

<uninstall_package_names>
hunspell-bn
</uninstall_package_names>

</app>
